@@ -1,5 +1,6 @@
 from _fitting import fitting
-from pyrap.functionals import *
+from casacore.functionals import *
+from casacore import six
 import numpy as NUM
 
 class fitserver(object):
@@ -10,7 +11,7 @@ class fitserver(object):
     conjugate (complex with both the unknown and its conjugate in the
     condition equations), separable complex, asreal complex with the real and
     imaginary part seen as independent unknowns. All solutions need a model
-    (specified as a :mod:`pyrap.functionals`. All solutions are done using an
+    (specified as a :mod:`casacore.functionals`. All solutions are done using an
     SVD type method. A collinearity factor can be specified, which is in
     essence the sine squared of the minimum angle between two normal equation
     columns that are still to be considered independent. For automatic
@@ -221,7 +222,7 @@ class fitserver(object):
                 functional("hyper", len(x)).todict()
         self._fitids[fid]["constraint"][i]["x"] = [float(v) for v in x]
         self._fitids[fid]["constraint"][i]["y"] = float(y)
-        print self._fitids[fid]["constraint"]
+        six.print_(self._fitids[fid]["constraint"])
 
     def fitpoly(self, n, x, y, sd=None, wt=1.0, fid=0):
         if self.set(n=n+1, fid=fid):
