@@ -43,7 +43,7 @@ Several utility functions exist. Important ones are:
 # Make interface to class TableProxy available.
 from _tables import Table
 from tablehelper import _add_prefix, _remove_prefix, _do_remove_prefix
-
+from casacore import six
 
 # Execute a TaQL command on a table.
 def taql (command, style='Python', tables=[], globals={}, locals={}):
@@ -87,11 +87,11 @@ def taql (command, style='Python', tables=[], globals={}, locals={}):
     for tab in tables:
         tabs += [tab]
     try:
-        import pyrap.util
+        import casacore.util
         if len(locals) == 0:
             # local variables in caller are 3 levels up from getlocals
-            locals = pyrap.util.getlocals(3)
-        cmd = pyrap.util.substitute(cmd, [(table, '', tabs)], globals, locals)
+            locals = casacore.util.getlocals(3)
+        cmd = casacore.util.substitute(cmd, [(table, '', tabs)], globals, locals)
     except:
         pass
     if style:
@@ -294,7 +294,7 @@ class table(Table):
                 Table.__init__ (self, tabname, lockopt, endian,
                                 memtype, nrow, tabledesc, dminfo);
                 if ack:
-                    print 'Successful creation of', lockopt['option']+'-locked table', tabname+':', self.ncols(), 'columns,', self.nrows(), 'rows';
+                    six.print_('Successful creation of', lockopt['option']+'-locked table', tabname+':', self.ncols(), 'columns,', self.nrows(), 'rows')
             else:
                 # Deal with existing tables.
                 if not tabname:
@@ -310,17 +310,17 @@ class table(Table):
                 if isinstance(tabname,str):
                     Table.__init__ (self, tabname, lockopt, opt);
                     if ack:
-                        print 'Successful', typstr, 'open of', lockopt['option']+'-locked table', tabname+':', self.ncols(), 'columns,', self.nrows(), 'rows';
+                        six.print_('Successful', typstr, 'open of', lockopt['option']+'-locked table', tabname+':', self.ncols(), 'columns,', self.nrows(), 'rows')
                 elif isinstance(tabname[0],str):
                     # Concatenate and open named tables.
                     Table.__init__ (self, tabname, concatsubtables, lockopt, opt)
                     if ack:
-                        print 'Successful', typstr, 'open of', lockopt['option']+'-locked concatenated tables', tabname,':', self.ncols(), 'columns,', self.nrows(), 'rows';
+                        six.print_('Successful', typstr, 'open of', lockopt['option']+'-locked concatenated tables', tabname,':', self.ncols(), 'columns,', self.nrows(), 'rows')
                 else:
                     # Concatenate already open tables.
                     Table.__init__ (self, tabname, concatsubtables, 0, 0, 0)
                     if ack:
-                        print 'Successful virtual concatenation of', len(tabname), 'tables:', self.ncols(), 'columns,', self.nrows(), 'rows';
+                        six.print_('Successful virtual concatenation of', len(tabname), 'tables:', self.ncols(), 'columns,', self.nrows(), 'rows')
         # Create a row object for this table.
         self._makerow()
 
@@ -545,7 +545,7 @@ class table(Table):
         msg = self._toascii (asciifile, headerfile, columnnames, sep,
                              precision, usebrackets)
         if len(msg) > 0:
-            print msg
+            six.print_(msg)
 
     def rename (self, newtablename):
         """Rename the table.
@@ -1127,14 +1127,14 @@ class table(Table):
         tdesc = desc
         # Create a tabdesc if only a coldesc is given.
         if desc.has_key('name'):
-            import pyrap.tables.tableutil
+            import casacore.tables.tableutil
             if len(desc)==2 and desc.has_key('desc'):
                 # Given as output from makecoldesc
-                tdesc = pyrap.tables.tableutil.maketabdesc(desc);
+                tdesc = casacore.tables.tableutil.maketabdesc(desc);
             elif desc.has_key('valueType'):
             # Given as output of getcoldesc (with a name field added)
-                cd = pyrap.tables.tableutil.makecoldesc (desc['name'], desc)
-                tdesc = pyrap.tables.tableutil.maketabdesc(cd)
+                cd = casacore.tables.tableutil.makecoldesc (desc['name'], desc)
+                tdesc = casacore.tables.tableutil.maketabdesc(cd)
         self._addcols (tdesc, dminfo, addtoparent)
         self._makerow()
 
@@ -1512,24 +1512,24 @@ class table(Table):
         tables referenced by table keywords.
 
         """
-        print 'Table summary:', self.name();
-        print 'Shape:', self.ncols(), 'columns by', self.nrows(), 'rows';
-        print 'Info:', self.info();
+        six.print_('Table summary:', self.name())
+        six.print_('Shape:', self.ncols(), 'columns by', self.nrows(), 'rows')
+        six.print_('Info:', self.info())
         tkeys = self.getkeywords();
         if (len(tkeys) > 0):
-            print 'Table keywords:', tkeys;
+            six.print_('Table keywords:', tkeys)
         columns = self.colnames();
         if (len(columns) > 0):
-            print 'Columns:', columns;
+            six.print_('Columns:', columns)
             for column in columns:
                 ckeys = self.getcolkeywords(column);
                 if (len(ckeys) > 0):
-                    print column, 'keywords:', ckeys;
+                    six.print_(column, 'keywords:', ckeys)
         if (recurse):
             for key in tkeys.keys():
                 value = tkeys[key];
                 tabname = _remove_prefix (value);
-                print 'Summarizing subtable:', tabname;
+                six.print_('Summarizing subtable:', tabname)
                 lt = table(tabname);
                 if (not lt.summary(recurse)):
                     break;
@@ -1718,34 +1718,34 @@ class table(Table):
                 waitstr1 = " &";
                 waitstr2 = "background ...";
             if self.iswritable():
-                print "Flushing data and starting casabrowser in the " + waitstr2
+                six.print_("Flushing data and starting casabrowser in the " + waitstr2)
             else:
-                print "Starting casabrowser in the " + waitstr2
+                six.print_("Starting casabrowser in the " + waitstr2)
             self.flush()
             self.unlock()
             if os.system('test -e ' + self.name() + '/table.dat') == 0:
                 os.system ('casabrowser ' + self.name() + waitstr1)
             elif len(tempname) > 0:
-                print "  making a persistent copy in table " + tempname
+                six.print_("  making a persistent copy in table " + tempname)
                 tx = self.copy (tempname);
                 tx = 0;
                 os.system ('casabrowser ' + tempname + waitstr1)
                 if wait:
-                    from pyrap.tables import tabledelete
-                    print "  finished browsing"
+                    from casacore.tables import tabledelete
+                    six.print_("  finished browsing")
                     tabledelete (tempname);
 
                 else:
-                    print "  after browsing use tabledelete('" + tempname + "') to delete the copy"
+                    six.print_("  after browsing use tabledelete('" + tempname + "') to delete the copy")
             else:
-                print "Cannot browse because the table is in memory only."
-                print "You can browse a (shallow) persistent copy of the table like:"
-                print "   t.browse(True, '/tmp/tab1')"
+                six.print_("Cannot browse because the table is in memory only.")
+                six.print_("You can browse a (shallow) persistent copy of the table like:")
+                six.print_("   t.browse(True, '/tmp/tab1')")
         else:
             try:
                 import wxPython
             except ImportError:
-                print 'casabrowser nor wx available'
+                six.print_('casabrowser nor wx available')
                 return
             from wxPython.wx import wxPySimpleApp
             import sys
@@ -1801,30 +1801,30 @@ class table(Table):
                     waitstr1 = " &";
                     waitstr2 = "background ...";
                 if self.iswritable():
-                    print "Flushing data and starting casaviewer in the " + waitstr2
+                    six.print_("Flushing data and starting casaviewer in the " + waitstr2)
                 else:
-                    print "Starting casaviewer in the " + waitstr2
+                    six.print_("Starting casaviewer in the " + waitstr2)
                 self.flush()
                 self.unlock()
                 if os.system('test -e ' + self.name() + '/table.dat') == 0:
                     os.system ('casaviewer ' + self.name() + waitstr1)
                     viewed = True
                 elif len(tempname) > 0:
-                    print "  making a persistent copy in table " + tempname
-                    tx = self.copy (tempname);
-                    tx = 0;
+                    six.print_("  making a persistent copy in table " + tempname)
+                    tx = self.copy (tempname)
+                    tx = 0
                     os.system ('casaviewer ' + tempname + waitstr1)
                     viewed = True
                     if wait:
-                        from pyrap.tables import tabledelete
-                        print "  finished viewing"
+                        from casacore.tables import tabledelete
+                        six.print_("  finished viewing")
                         tabledelete (tempname);
                     else:
-                        print "  after viewing use tabledelete('" + tempname + "') to delete the copy"
+                        six.print_("  after viewing use tabledelete('" + tempname + "') to delete the copy")
                 else:
-                    print "Cannot browse because the table is in memory only."
-                    print "You can browse a (shallow) persistent copy of the table like:"
-                    print "   t.view(True, '/tmp/tab1')"
+                    six.print_("Cannot browse because the table is in memory only.")
+                    six.print_("You can browse a (shallow) persistent copy of the table like:")
+                    six.print_("   t.view(True, '/tmp/tab1')")
         # Could not view the table, so browse it.
         if not viewed:
             self.browse (wait, tempname)
